==> search-value-right-2.9.43.tgz: package/README.md <==
Finds last index of a value. [:running:] [:vhs:] [:package:] [:moon:] [:ledger:]
> Alternatives: [searchValue], [searchValueRight], [searchValueAll].
> Similar: [search], [scan], [find].<br>
> This is part of package [extra-array].

[extra-array]: https://www.npmjs.com/package/extra-array

```javascript
iterable.searchValueRight(x, v, [fc], [fm]);
// x:  an iterable
// v:  search value
// fc: compare function (a, b)
// fm: map function (v, i, x)
// --> index of value, -1 if not found
```

```javascript
const iterable = require('extra-iterable');

var x = [1, 2, 3, 2, 5];
iterable.searchValueRight(x, 2);
// 3              ^

var x = [1, 2, 3, -2, 5];
iterable.searchValueRight(x, 2, (a, b) => Math.abs(a) - Math.abs(b));
// 3               ^

iterable.searchValueRight(x, 2, null, v => Math.abs(v));
// 3               ^
```

### references

- [List-Extra.elemIndex: elm](https://package.elm-lang.org/packages/elm-community/list-extra/7.1.0/List-Extra#elemIndex)
- [iterable-binsearch: @krisselden](https://www.npmjs.com/package/iterable-binsearch)
- [binarysearch: @soldair](https://www.npmjs.com/package/binarysearch)

[search]: https://github.com/nodef/extra-iterable/wiki/search
[searchRight]: https://github.com/nodef/extra-iterable/wiki/searchRight
[searchAll]: https://github.com/nodef/extra-iterable/wiki/searchAll
[:running:]: https://npm.runkit.com/@extra-iterable/search-value-right
[:package:]: https://www.npmjs.com/package/@extra-iterable/search-value-right
[:moon:]: https://www.npmjs.com/package/@extra-iterable/search-value-right.min
[:ledger:]: https://unpkg.com/@extra-iterable/search-value-right/
[searchValue]: https://github.com/nodef/extra-iterable/wiki/searchValue
[searchValueRight]: https://github.com/nodef/extra-iterable/wiki/searchValueRight
[searchValueAll]: https://github.com/nodef/extra-iterable/wiki/searchValueAll
[scan]: https://github.com/nodef/extra-iterable/wiki/scan
[find]: https://github.com/nodef/extra-iterable/wiki/find
[:vhs:]: https://asciinema.org/a/339822

==> search-value-right-2.9.45.tgz: package/README.md <==
Finds last index of a value. [:running:] [:vhs:] [:package:] [:moon:] [:ledger:]
> Alternatives: [searchValue], [searchValueRight], [searchValueAll].
> Similar: [search], [scan], [find].<br>
> This is part of package [extra-array].

[extra-array]: https://www.npmjs.com/package/extra-array

```javascript
array.searchValueRight(x, v, [fc], [fm]);
// x:  an array
// v:  search value
// fc: compare function (a, b)
// fm: map function (v, i, x)
// --> index of value, -1 if not found
```

```javascript
const iterable = require('extra-iterable');

var x = [1, 2, 3, 2, 5];
iterable.searchValueRight(x, 2);
// 3              ^

var x = [1, 2, 3, -2, 5];
iterable.searchValueRight(x, 2, (a, b) => Math.abs(a) - Math.abs(b));
// 3               ^

iterable.searchValueRight(x, 2, null, v => Math.abs(v));
// 3               ^
```

### references

- [List-Extra.elemIndex: elm](https://package.elm-lang.org/packages/elm-community/list-extra/7.1.0/List-Extra#elemIndex)
- [iterable-binsearch: @krisselden](https://www.npmjs.com/package/iterable-binsearch)
- [binarysearch: @soldair](https://www.npmjs.com/package/binarysearch)

[search]: https://github.com/nodef/extra-iterable/wiki/search
[searchRight]: https://github.com/nodef/extra-iterable/wiki/searchRight
[searchAll]: https://github.com/nodef/extra-iterable/wiki/searchAll
[:running:]: https://npm.runkit.com/@extra-iterable/search-value-right
[:package:]: https://www.npmjs.com/package/@extra-iterable/search-value-right
[:moon:]: https://www.npmjs.com/package/@extra-iterable/search-value-right.min
[:ledger:]: https://unpkg.com/@extra-iterable/search-value-right/
[searchValue]: https://github.com/nodef/extra-iterable/wiki/searchValue
[searchValueRight]: https://github.com/nodef/extra-iterable/wiki/searchValueRight
[searchValueAll]: https://github.com/nodef/extra-iterable/wiki/searchValueAll
[scan]: https://github.com/nodef/extra-iterable/wiki/scan
[find]: https://github.com/nodef/extra-iterable/wiki/find
[:vhs:]: https://asciinema.org/a/339822
[:running:]: https://npm.runkit.com/@extra-array/search-value-right
[:package:]: https://www.npmjs.com/package/@extra-array/search-value-right
[:moon:]: https://www.npmjs.com/package/@extra-array/search-value-right.min
[:ledger:]: https://unpkg.com/@extra-array/search-value-right/
